==> qtjambi-qt3drender-6.2.7-sources.jar: io/qt/qt3d/render/QNoPicking.java <==
package io.qt.qt3d.render;


/**
 * <p>When a Qt3DRender::QNoPicking node is present in a FrameGraph branch, this prevents the render aspect from performing picking selection for the given branch</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qnopicking.html">Qt3DRender::QNoPicking</a></p>
 */
public class QNoPicking extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QNoPicking.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QNoPicking(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QNoPicking() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QNoPicking(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QNoPicking instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNoPicking(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QNoPicking(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QNoPicking instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.2.11-sources.jar: io/qt/qt3d/render/QNoPicking.java <==
package io.qt.qt3d.render;


/**
 * <p>When a Qt3DRender::QNoPicking node is present in a FrameGraph branch, this prevents the render aspect from performing picking selection for the given branch</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qnopicking.html">Qt3DRender::QNoPicking</a></p>
 */
public class QNoPicking extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QNoPicking.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QNoPicking(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QNoPicking() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QNoPicking(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QNoPicking instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNoPicking(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QNoPicking(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QNoPicking instance, QDeclarativeConstructor constructor);
    
}
